=====
Usage
=====

To launch RofiPaste from the command line simply type `rofipaste`
Once you've set your paste files, bind a keyboard shortcut to RofiPaste to access the content of your file from everywhere.



Dynamic pastes
--------------

You can create "dynamic pastes" by writing scripts and using a shebang

For instance, if you want an entry to paste the date:

.. code-block:: bash

    #!/bin/bash
    date


*TIPS: You can use your clipboard as an input for your scripts*
